@@ -16,6 +16,7 @@ pub enum Msg {
     Close(u16),
     Ping(Vec<u8>),
     Pong(Vec<u8>),
+    Clear(),
 }
 
 
@@ -36,6 +37,7 @@ impl Msg {
             Msg::Close(_) => "close",
             Msg::Ping(_) => "ping",
             Msg::Pong(_) => "pong",
+            Msg::Clear() => "clear",
         }
     }
 }
